@@ -293,9 +293,8 @@ EOD;
     if ($text_selector == 1) {
       $query .= " AND (MATCH (summary, contents) AGAINST ('$search_text' IN BOOLEAN MODE) OR summary LIKE '%$search_text%' OR CONTENTS LIKE '%$search_text%') ";
     }
-    // Notes get ordered by the automatic increasing id. 
-    // That would sort the notes in the order of their entry.
-    $query .= " ORDER BY id ";
+    // Notes get ordered by the passage they refer to. It is a rough method and better ordering is needed. 
+    $query .= " ORDER BY passage ";
     // Limit the selection if a limit is given.
     if (is_numeric ($limit)) {
       $limit = Database_SQLInjection::no ($limit);
@@ -771,6 +770,21 @@ EOD;
 
 
 
+  /**
+  * Returns the raw passage text of the note identified by $identifier.
+  */  
+  public function getRawPassage ($identifier)
+  {
+    $server = Database_Instance::getInstance ();
+    $identifier = Database_SQLInjection::no ($identifier);
+    $query = "SELECT passage FROM notes WHERE identifier = $identifier;";
+    $result = $server->runQuery ($query);
+    $row = $result->fetch_row();
+    $rawpassage = $row[0];
+    return $rawpassage;
+  }
+
+
   /**
   * Gets the raw status of a note.
   * Returns it as a string.
@@ -1001,6 +1015,29 @@ EOD;
   }
 
 
+  /**
+  * Returns an array of duplicate note identifiers selected.
+  */
+  public function selectDuplicateNotes ($rawpassage, $summary, $contents)
+  {
+    $identifiers = array ();
+    $server = Database_Instance::getInstance ();
+    $rawpassage = Database_SQLInjection::no ($rawpassage);
+    $summary = Database_SQLInjection::no ($summary);
+    $contents = Database_SQLInjection::no ($contents);
+    $query = "SELECT identifier FROM notes WHERE passage = '$rawpassage' AND summary = '$summary' AND contents = '$contents';";
+    $result = $server->runQuery ($query);
+    for ($i = 0; $i < $result->num_rows; $i++) {
+      $row = $result->fetch_row();
+      $identifier = $row[0];
+      $identifiers []= $identifier;
+    }
+    return $identifiers;
+  }
+  
+  
+
+
 
 
   
