@@ -79,6 +79,9 @@ userstring3 varchar (512)
 EOD;
     $database_instance = Database_Instance::getInstance();
     $database_instance->runQuery ($str);
+    // Update the left margin and the first line indent for the standard note contents styles.
+    $database_instance->runQuery ("UPDATE styles SET leftmargin = 5 WHERE (marker = 'ft' OR marker = 'xt') AND leftmargin = 0;");
+    $database_instance->runQuery ("UPDATE styles SET firstlineindent = -5 WHERE (marker = 'ft' OR marker = 'xt') AND firstlineindent = 0;");
   }
 
 
@@ -328,7 +331,7 @@ EOD;
     if ($result->num_rows > 0) {
       $data = $result->fetch_assoc();
     }
-    // Pad the color with preceding zeroes so the color shows properly in the html page..
+    // Pad the color with preceding zeroes so the color shows properly in the html page.
     $data['color'] = str_pad ($data['color'], 6, "0", STR_PAD_LEFT);
     return $data;
   }
