@@ -26,7 +26,7 @@
   }
   closedir($handler);
   if ($files_writable) {
-    echo "<p>Ok: Files are writeable</p>";
+    echo "<p>Ok: Files writeable</p>";
   } else {
     echo "<p>Error: Could not make files writeable</p>";
     die;
@@ -35,24 +35,13 @@
 
   // Smarty template compile directory writeable.
   if (is_writable ("smarty/templates_c")) {
-    echo "<p>Ok: Smarty compile directory is writeable</p>";
+    echo "<p>Ok: Smarty compile directory writeable</p>";
   } else {
     echo "<p>Error: Smarty compile directory is not writeable</p>";
     die;
   }
   flush ();
 
-  // Check on php-cli.
-  $php_cli = exec ("php -v 2>&1", &$output, &$return_var);
-  foreach ($output as $line) echo "<p>$line</p>";
-  if ($return_var == 0) {
-    echo "<p>Ok: PHP-cli is okay</p>";
-  } else {
-    echo "<p>Error: PHP-cli is not present or does not run properly</p>";
-    die;
-  }
-  flush ();
-   
   // If the user posted new values for accessing the database, write these to file.
   if (isset($_POST['submit'])) {
     $name   = $_POST['name'];
