@@ -43,10 +43,18 @@ class Timer_Receiver
         $subject = $message->subject;
         $log = "Processing email from $from with subject $subject";
         $database_log->log ($log);
-        $body = $message->getContent ();
+        $body = Filter_Email::extractPlainTextMessage ($message);
+        $body = $body->__toString ();
         $body = strip_tags ($body);
         $confirm_worker = Confirm_Worker::getInstance ();
-        if (!$confirm_worker->handleEmail ($from, $subject, $body)) {
+        $notes_logic = Notes_Logic::getInstance ();
+        if ($confirm_worker->handleEmail ($from, $subject, $body)) {
+        } 
+        else if ($notes_logic->handleEmailComment ($from, $subject, $body)) {
+        }
+        else if ($notes_logic->handleEmailNew ($from, $subject, $body)) {
+        }
+        else {
           $log = "Could not allocate email from $from, subject $subject";
           $database_log->log ($log);
           $database_log->log ($body);
